@@ -3,6 +3,7 @@ use v6.c;
 use HTTP::Server::Ogre;
 
 use Bailador::Command;
+use Bailador::Utils;
 
 class Bailador::Command::ogre does Bailador::Command {
     method run(:$app) {
@@ -13,7 +14,7 @@ class Bailador::Command::ogre does Bailador::Command {
         my $msg     = "Entering the dance floor{ $config.mode eq 'development' ?? ' in development mode' !! ''}: http://$host:$port";
 
         given HTTP::Server::Ogre.new(:$host, :$port, :app($p6w-app)) {
-            say $msg;
+            terminal-color($msg, 'green', $config);
             .run;
         }
     }
