@@ -2,6 +2,7 @@ use v6.c;
 
 use Bailador::App;
 use Bailador::Route;
+use Bailador::Route::Controller;
 use Bailador::Route::Prefix;
 use Bailador::Route::Simple;
 use Bailador::Route::StaticFile;
@@ -17,8 +18,20 @@ multi sub make-prefix-route($url-matcher, Callable $prefix-enter-code) is export
     Bailador::Route::Prefix.new( :@method, :$url-matcher, :$prefix-enter-code );
 }
 
-multi sub make-simple-route(Str $method, Pair $x) is export {
-    Bailador::Route::Simple.new( :$method, url-matcher => $x.key, code => $x.value);
+multi sub make-route(Str $method, Pair $x) is export {
+    make-route($method, $x.key, $x.value);
+}
+multi sub make-route(Str $method, $url-matcher, Callable $code) is export {
+    Bailador::Route::Simple.new( :$method, :$url-matcher, :$code);
+}
+
+multi sub make-route(Str $method, $url-matcher, %param) is export {
+    die "there must be a 'class' or 'controller'" unless %param<class> || %param<controller>;
+    die "no method specified with 'to'"           unless %param<to>;
+    Bailador::Route::Controller.new(:$method, :$url-matcher, |%param);
+}
+
+sub make-simple-route(Str $method, Pair $x) is export {
 }
 
 sub make-static-dir-route(Pair $x, Bailador::App $app) is export {
